Methods
=======

All methods infer float precision based on the input (32bit or 64bit).

.. currentmodule:: pysplashsurf

.. autofunction:: check_mesh_consistency

.. autofunction:: convert_tris_to_quads

.. autofunction:: create_aabb_object

.. autofunction:: create_aabb_object_from_points

.. autofunction:: create_mesh_with_data_object

.. autofunction:: create_sph_interpolator_object

.. autofunction:: decimation

.. autofunction:: marching_cubes_cleanup

.. autofunction:: neighborhood_search_spatial_hashing_parallel

.. autofunction:: par_laplacian_smoothing_inplace

.. autofunction:: par_laplacian_smoothing_normals_inplace

.. autofunction:: reconstruct_surface

.. autofunction:: reconstruction_pipeline

.. autofunction:: write_to_file